*** Author: Jules Gazeaud
*** Date: April 03, 2022
*** Description: This do-file creates the tables and figures in the paper


* TABLES 1-3
* ------------

	** Women sample
	
	use "${data}/data_women.dta" , clear
	
	
	
		*Preparation

		do "${data}/Lasso_var.do"		
		local i = 1
		gen pvalue_t0 = .
		gen pvalue_t1 = .
		gen pvalue_t2 = .
		gen pvalue_t3 = .
		gen varname = ""
		
		
		
		** Outcomes with no baseline value for the outcomes (not ANCOVA)
	
		foreach var in 	iga_precovid c3_haveskills ///
						c1_headjob c1_othermembersworkn c1_headincome30 c1_incomeotheriga c1_hengag_agr chemicals ///
						value19_n_iga z_financial_index  z_agency_index c1_cropprodna c1_cropvalna ///
						d1_ladder_present d1_ladder_1ago d1_ladder3years d1_ladderwealth mhi5 ///
						z_assets19_total migration_future_d hh_migrated {
	
				noi di "`var'"
				replace varname = "`var'" if _n == `i'
				sum `var' if trt_cash == 0
				local sd = `r(sd)'
				insert_into_file using "sample_table.csv", key(`var'_cmean) value(" `r(mean)'") format(%6.3f)
				insert_into_file using "sample_table.csv", key(`var'_csd) value(" `sd'") format(%6.3f)
				
				** Equation 1
				local temp = "`var'"
				if "`temp'" != "hh_migrated" {
				pdslasso `var' trt_cash ($balance $X_poly_and_int i.a1_enumerator) , partial(i.a1_enumerator) robust
				}
				if "`temp'" == "hh_migrated" {
				pdslasso `var' trt_cash ($balance $X_poly_and_int) , robust				
				}
				mat A = r(table)
				local p = A[4,1]
				replace pvalue_t0 = `p' if _n == `i'
				store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t) all
			
		
				** Equation 2
				if "`temp'" != "hh_migrated" {
				pdslasso `var' trt_cash_0 trt_cash_1 ($balance $X_poly_and_int i.a1_enumerator) , partial(i.a1_enumerator) robust
				}
				if "`temp'" == "hh_migrated" {
				pdslasso `var' trt_cash_0 trt_cash_1 ($balance $X_poly_and_int) , robust
				}
				mat A = r(table)
				local p0 = A[4,1]
				replace pvalue_t1 = `p0' if _n == `i'
				local p1 = A[4,2]
				replace pvalue_t2 = `p1' if _n == `i'
				store_est_tpl using "sample_table.csv" , coef(trt_cash_0) name(`var'_t0) all
				store_est_tpl using "sample_table.csv" , coef(trt_cash_1) name(`var'_t1) all				
				local n = `e(N)'
				insert_into_file using "sample_table.csv", key(`var'_t1_n) value(" `n'") format(%-9.0fc)
				test trt_cash_0 = trt_cash_1
				replace pvalue_t3 = `r(p)' if _n == `i'
				local ++i

				insert_into_file using "sample_table.csv", key(`var'_test) value(" `r(p)'") format(%6.3f)
		
		}
		
		
	

		** Outcomes with baseline value for the outcomes (ANCOVA)
		
		foreach var in 		c1_job_iga business_profit business_employee total_employement ///
							value_n_iga does_livestock conso_tot_pc conso_food_pc conso_nofood_pc ///
							z_assets_total b4_econshock b4_othershock b4_extreme b4_normal migration_d {
				
				noi di "`var'"
				replace varname = "`var'" if _n == `i'
				sum `var' if trt_cash == 0
				local sd = `r(sd)'
				insert_into_file using "sample_table.csv", key(`var'_cmean) value(" `r(mean)'") format(%6.3f)
				insert_into_file using "sample_table.csv", key(`var'_csd) value(" `sd'") format(%6.3f)
				
				* Equation 1
				pdslasso `var' trt_cash ($balance $X_poly_and_int `var'_bl i.a1_enumerator) , partial(i.a1_enumerator `var'_bl) robust
				mat A = r(table)
				local p = A[4,1]
				replace pvalue_t0 = `p' if _n == `i'
				store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t) all

				
				* Equation 2
				pdslasso `var' trt_cash_0 trt_cash_1 ($balance $X_poly_and_int `var'_bl i.a1_enumerator) , partial(i.a1_enumerator `var'_bl) robust
				mat A = r(table)
				local p0 = A[4,1]
				replace pvalue_t1 = `p0' if _n == `i'
				local p1 = A[4,2]
				replace pvalue_t2 = `p1' if _n == `i'
				store_est_tpl using "sample_table.csv" , coef(trt_cash_0) name(`var'_t0) all
				store_est_tpl using "sample_table.csv" , coef(trt_cash_1) name(`var'_t1) all
				local n = `e(N)'
				insert_into_file using "sample_table.csv", key(`var'_t1_n) value(" `n'") format(%-9.0fc)
				test trt_cash_0 = trt_cash_1
				replace pvalue_t3 = `r(p)' if _n == `i'
				local ++i
				insert_into_file using "sample_table.csv", key(`var'_test) value(" `r(p)'") format(%6.3f)

		}
		
		
		
		** Partner sample	
		preserve
		use "${data}/data_partners.dta" , clear
		do "${data}/Lasso_var.do"
		foreach var in z_male_index {
		sum `var' if trt_cash_part_1==0
		local sd = `r(sd)'
		insert_into_file using "sample_table.csv", key(`var'_cmean) value(" `r(mean)'") format(%6.3f)
		insert_into_file using "sample_table.csv", key(`var'_csd) value(" `sd'") format(%6.3f)
		pdslasso `var' trt_cash_part_1 ($balance $X_poly_and_int i.a1_enumerator) , partial(i.a1_enumerator) robust
		mat A = r(table)
		local p_dialogue = A[4,1]
		di `p_dialogue'
		store_est_tpl using "sample_table.csv" , coef(trt_cash_part_1) name(`var'_t1) all
		}
		restore
	
		
		** FDR q-values
		drop if pvalue_t0==. 
		keep pvalue* varname	
		reshape long pvalue_t , i(varname) j(t)
		set obs `=_N+1'
		replace varname = "z_male_index" if _n == 145
		replace pvalue_t = `p_dialogue' if _n == 145
		replace t = 2 if _n == 145
		rename pvalue_t pval
		do "${data}/fdr_sharpened_qvalues.do"
		foreach var in c1_job_iga iga_precovid business_profit business_employee total_employement c3_haveskills c1_headjob c1_othermembersworkn c1_headincome30 c1_incomeotheriga /// 
						c1_hengag_agr chemicals c1_cropprodna c1_cropvalna does_livestock value19_n_iga value_n_iga /// 
						z_financial_index z_agency_index d1_ladder_present d1_ladder_1ago d1_ladder3years d1_ladderwealth mhi5 /// 
						conso_tot_pc conso_food_pc conso_nofood_pc z_assets_total z_assets19_total migration_d hh_migrated migration_future_d b4_econshock b4_othershock b4_extreme b4_normal z_male_index {
		sum bky06_qval if varname == "`var'" & t == 0
		insert_into_file using sample_table.csv, key(`var'_qpvalue_t) value(" `r(mean)'") format(%6.3f)
		sum bky06_qval if varname == "`var'" & t == 1
		insert_into_file using sample_table.csv, key(`var'_qpvalue_t0) value(" `r(mean)'") format(%6.3f)
		sum bky06_qval if varname == "`var'" & t == 2
		insert_into_file using sample_table.csv, key(`var'_qpvalue_t1) value(" `r(mean)'") format(%6.3f)
		sum bky06_qval if varname == "`var'" & t == 3
		insert_into_file using sample_table.csv, key(`var'_qpvalue_test) value(" `r(mean)'") format(%6.3f) 
		}



		
	table_from_tpl, t("TPL_tab1.tex") r("sample_table.csv") o("tab1.tex")
	table_from_tpl, t("TPL_tab2.tex") r("sample_table.csv") o("tab2.tex")
	table_from_tpl, t("TPL_tab3.tex") r("sample_table.csv") o("tab3.tex")
		

	



* TABLE A2 
* ----------

	use "${data}/data_women.dta" , clear
		
		drop if Intervention == "Cash Grants - Partenaire"
		replace trt_cash_1 = . if trt_cash_0 == 1
		replace trt_cash_0 = . if trt_cash_1 == 1
		
		* Means, sd and ttests and normalized diff
		foreach var in $balance {
		forvalues x = 0/2 {
		sum `var' if group == `x'
		local sd = `r(sd)'
		local n = `r(N)'
		insert_into_file using "sample_table.csv", key(`var'_mean`x') value(" `r(mean)'") format(%6.3f)
		insert_into_file using "sample_table.csv", key(`var'_sd`x') value(" `sd'") format(%6.3f)
		insert_into_file using "sample_table.csv", key(`var'_n`x') value(" `n'") format(%-9.0fc)
		ttest `var' , by(trt_cash_`x')
		local n1 = `r(N_1)'
		local n2 = `r(N_2)'
		local ntot = `n1' + `n2'
		insert_into_file using "sample_table.csv", key(`var'_p`x') value(" `r(p)'") format(%6.3f)
		insert_into_file using "sample_table.csv", key(`var'_ntot`x') value(" `ntot'") format(%-9.0fc)
		stddiff `var' , by(trt_cash_`x')
		matrix b = r(output)
		local ndiff = b[1,5]	
		insert_into_file using "sample_table.csv", key(`var'_ndiff`x') value(" `ndiff'") format(%6.3f)
		}
		}
		
		* Omnibus test
		forvalues x = 0/2 {
		reg trt_cash_`x'	$balance
		test $balance
		insert_into_file using "sample_table.csv", key(omnip`x') value(" `r(p)'") format(%6.3f)
		}
		
	table_from_tpl, t("TPL_tabA2.tex") r("sample_table.csv") o("tabA2.tex")
		



* TABLE A3
* ---------

	use "${data}/data_women.dta" , clear
		
		drop if Intervention == "Cash Grants - Partenaire"
		replace trt_cash_1 = . if trt_cash_0 == 1
		replace trt_cash_0 = . if trt_cash_1 == 1
		
		foreach var in attrition_tot attrition Dead Moved Refusal Other {
		forvalues x = 0/2 {
		sum `var' if group == `x'
		local sd = `r(sd)'
		local n = `r(N)'
		insert_into_file using "sample_table.csv", key(`var'_mean`x') value(" `r(mean)'") format(%6.3f)
		insert_into_file using "sample_table.csv", key(`var'_sd`x') value(" `sd'") format(%6.3f)
		insert_into_file using "sample_table.csv", key(`var'_n`x') value(" `n'") format(%-9.0fc)
		ttest `var' , by(trt_cash_`x')
		local n1 = `r(N_1)'
		local n2 = `r(N_2)'
		local ntot = `n1' + `n2'
		insert_into_file using "sample_table.csv", key(`var'_p`x') value(" `r(p)'") format(%6.3f)
		insert_into_file using "sample_table.csv", key(`var'_ntot`x') value(" `ntot'") format(%-9.0fc)
		stddiff `var' , by(trt_cash_`x')
		matrix b = r(output)
		local ndiff = b[1,5]	
		insert_into_file using "sample_table.csv", key(`var'_ndiff`x') value(" `ndiff'") format(%6.3f)
		}
		}
		
	table_from_tpl, t("TPL_tabA3.tex") r("sample_table.csv") o("tabA3.tex")



		
* TABLE A4
* ---------

	use "${data}/data_women.dta" , clear
		
		replace trt_cash_1 = . if trt_cash_0 == 1
		replace trt_cash_0 = . if trt_cash_1 == 1
		drop if Intervention == "Cash Grants - Partenaire" | attrition == 1
		
		* Means, sd and ttests and normalized diff
		foreach var in $balance {
		forvalues x = 0/2 {
		sum `var' if group == `x'
		local sd = `r(sd)'
		local n = `r(N)'
		insert_into_file using "sample_table.csv", key(`var'2_mean`x') value(" `r(mean)'") format(%6.3f)
		insert_into_file using "sample_table.csv", key(`var'2_sd`x') value(" `sd'") format(%6.3f)
		insert_into_file using "sample_table.csv", key(`var'2_n`x') value(" `n'") format(%-9.0fc)
		ttest `var' , by(trt_cash_`x')
		local n1 = `r(N_1)'
		local n2 = `r(N_2)'
		local ntot = `n1' + `n2'
		insert_into_file using "sample_table.csv", key(`var'2_p`x') value(" `r(p)'") format(%6.3f)
		insert_into_file using "sample_table.csv", key(`var'2_ntot`x') value(" `ntot'") format(%-9.0fc)
		stddiff `var' , by(trt_cash_`x')
		matrix b = r(output)
		local ndiff = b[1,5]	
		insert_into_file using "sample_table.csv", key(`var'2_ndiff`x') value(" `ndiff'") format(%6.3f)
		}
		}
		
		* Omnibus test
		forvalues x = 0/2 {
		reg trt_cash_`x' 	$balance
		test $balance
		insert_into_file using "sample_table.csv", key(omnip`x'2) value(" `r(p)'") format(%6.3f)
		}
		
	table_from_tpl, t("TPL_tabA4.tex") r("sample_table.csv") o("tabA4.tex")

			
			
* TABLE A5
* ---------

	use "${data}/data_women.dta" , clear
		
		drop if Intervention == "Cash Grants - Partenaire"
		count if diff_date >= 30.5 & trt_cash == 1 & diff_date != . // Trim 48 observations => 30.5 days
		count if vtracked == 1 & responded == 1 & trt_cash == 1
		
			* Preparation
			gen temp0 = 1 if attrition == 1 & trt_cash == 0
			gen temp1 = 1 if diff_date >= 30.5 & trt_cash == 1 & diff_date != .
			gen temp2 = 1 if vtracked == 1 & responded == 1 & trt_cash == 1
			
			gen temp_0 = 0 if attrition == 1 & trt_cash == 0
			replace temp_0 = 1 if diff_date >= 30.5 & trt_cash == 1 & diff_date != .
			gen temp_1 = 0 if attrition == 1 & trt_cash == 0
			replace temp_1 = 1 if vtracked == 1 & responded == 1 & trt_cash == 1
			gen temp_2 = 0 if diff_date >= 30.5 & trt_cash == 1 & diff_date != .
			replace temp_2 = 1 if vtracked == 1 & responded == 1 & trt_cash == 1
			expand 2 if (diff_date >= 30.5 & trt_cash == 1 & diff_date != .) & (vtracked == 1 & responded == 1 & trt_cash == 1) , gen(expanded_obs)
			replace temp_2 = 0 if expanded_obs == 1
			foreach var in temp0 temp1 temp2 temp_0 temp_1 {
			replace `var' = . if expanded_obs == 1
			}
			
			* Means, sd and ttests and normalized diff
			foreach var in $balance {
			forvalues x = 0/2 {
			sum `var' if temp`x' == 1
			local sd = `r(sd)'
			local n = `r(N)'
			insert_into_file using "sample_table.csv", key(`var'_mean`x'_behag) value(" `r(mean)'") format(%6.3f)
			insert_into_file using "sample_table.csv", key(`var'_sd`x'_behag) value(" `sd'") format(%6.3f)
			insert_into_file using "sample_table.csv", key(`var'_n`x'_behag) value(" `n'") format(%-9.0fc)
			ttest `var' , by(temp_`x')
			local n1 = `r(N_1)'
			local n2 = `r(N_2)'
			local ntot = `n1' + `n2'
			insert_into_file using "sample_table.csv", key(`var'_p`x'_behag) value(" `r(p)'") format(%6.3f)
			insert_into_file using "sample_table.csv", key(`var'_ntot`x'_behag) value(" `ntot'") format(%-9.0fc)
			stddiff `var' , by(temp_`x')
			matrix b = r(output)
			local ndiff = b[1,5]	
			insert_into_file using "sample_table.csv", key(`var'_ndiff`x'_behag) value(" `ndiff'") format(%6.3f)
			}
			}
			
	
			* Omnibus test
			forvalues x = 0/2 {
			reg temp_`x'	$balance
			test $balance
			insert_into_file using "sample_table.csv", key(omnip`x'_behag) value(" `r(p)'") format(%6.3f)
			}
		
	table_from_tpl, t("TPL_tabA5.tex") r("sample_table.csv") o("tabA5.tex")
		

									

	
	
* TABLES A6-A8
* -------------------
									
			*** A. IPW (column 2)
			* ---------------------
			
				use "${data}/data_women.dta" , clear
				drop if Intervention == "Follow up - TCLP"
				do "${data}/Lasso_var.do"	
				
				* Preparation
				global baseline_outcomes c1_job_iga_bl does_livestock_bl business_profit_bl business_employee_bl total_employement_bl conso_tot_pc_bl conso_food_pc_bl conso_nofood_pc_bl z_assets_total_bl value_n_bl value_n_iga_bl
				reg responded $balance $X_poly_and_int $baseline_outcomes , ro
				di e(r2_a)
				predict pscore
				bysort responded: sum pscore
				gen weight = 1/(1-pscore) if responded == 0
				replace weight = 1/pscore if responded == 1
				replace weight = . if attrition == 1
				
				* Analysis not ANCOVA
						foreach var in migration_future_d iga_precovid c3_haveskills c1_hengag_agr chemicals z_financial_index  z_agency_index c1_headjob c1_othermembersworkn c1_headincome30 c1_incomeotheriga c1_cropprodna c1_cropvalna value19_n_iga d1_ladder_present d1_ladder_1ago d1_ladder3years d1_ladderwealth mhi5 z_assets19_total {
						pdslasso `var' trt_cash ($balance $X_poly_and_int i.a1_enumerator) [pweight=weight], partial(i.a1_enumerator) robust
						store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t_ipw) all
						local n = `e(N)'
						insert_into_file using "sample_table.csv", key(`var'_t_ipw_n) value(" `n'") format(%-9.0fc)
						}
				
				* Analysis ANCOVA
						foreach var in b4_econshock b4_othershock b4_extreme b4_normal migration_d c1_job_iga does_livestock business_profit business_employee total_employement conso_tot_pc conso_food_pc conso_nofood_pc z_assets_total value_n_iga  {
						pdslasso `var' trt_cash ($balance $X_poly_and_int `var'_bl i.a1_enumerator) [pweight=weight], partial(i.a1_enumerator `var'_bl) robust
						store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t_ipw) all
						local n = `e(N)'
						insert_into_file using "sample_table.csv", key(`var'_t_ipw_n) value(" `n'") format(%-9.0fc)
						}		
			
						
			
			*** B. Behaghel
			* ------------------
			
					* Behagel et al bounds #1 (column 5)
					* Date of interview relative to Imada's median date
					* ----------------------------------------------------
					
					use "${data}/data_women.dta" , clear
					drop if Intervention == "Follow up - TCLP"
					do "${data}/Lasso_var.do"	
					drop if attrition == 1
					count if diff_date >= 30.5 & trt_cash == 1 & diff_date != . // Trim 48 observations => 30.5 days
					
					* Not ANCOVA
						foreach var in migration_future_d iga_precovid c3_haveskills c1_hengag_agr chemicals z_financial_index  z_agency_index c1_headjob c1_othermembersworkn c1_headincome30 c1_incomeotheriga c1_cropprodna c1_cropvalna value19_n_iga d1_ladder_present d1_ladder_1ago d1_ladder3years d1_ladderwealth mhi5 z_assets19_total {
						pdslasso `var' trt_cash ($balance $X_poly_and_int i.a1_enumerator) if (diff_date <= 30.5 & trt_cash == 1) | trt_cash == 0 , partial(i.a1_enumerator) robust
						store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t_behag) all
						local n = `e(N)'
						insert_into_file using "sample_table.csv", key(`var'_t_behag_n) value(" `n'") format(%-9.0fc)
						}
					
					* ANCOVA
						foreach var in b4_econshock b4_othershock b4_extreme b4_normal migration_d c1_job_iga does_livestock business_profit business_employee total_employement conso_tot_pc conso_food_pc conso_nofood_pc z_assets_total value_n_iga {
						pdslasso `var' trt_cash ($balance $X_poly_and_int `var'_bl i.a1_enumerator) if (diff_date <= 30.5 & trt_cash == 1) | trt_cash == 0 , partial(i.a1_enumerator `var'_bl) robust
						store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t_behag) all
						local n = `e(N)'
						insert_into_file using "sample_table.csv", key(`var'_t_behag_n) value(" `n'") format(%-9.0fc)
						}		
					
					
					
					* Behagel et al bounds #2 (columns 6-7)
					* Trim only very intensive tracking 
					* --------------------------------------
					
					use "${data}/data_women.dta" , clear
					drop if Intervention == "Follow up - TCLP"
					do "${data}/Lasso_var.do"	
					drop if attrition == 1					
					count if vtracked == 1 & responded == 1 & trt_cash == 1 // 30 interviews done after very intensive tracking in the treatment group
					
					* 88.8% respond in control group, 90.6% in treatment group before very intensive tracking
					forvalues x = 0/1 {
					gen resp`x'_1 = 1 if trt_cash == `x' & vtracked == 0 & responded == 1
					replace resp`x'_1 = 0 if trt_cash == `x' & resp`x'_1 == . 
					gen resp`x'_2 = 1 if trt_cash == `x' & responded == 1
					replace resp`x'_2 = 0 if trt_cash == `x' & resp`x'_2 == .
					}
					sum resp0_* resp1_* 
					* so trim (90.6-88.8)/90.6 = 2% of treated group surveyed before very intensive tracking 
					* this is (2*906)/100 = 18.12 observations - round to 18 observations trimmed 
					
					set seed 123456789
					gen random=uniform()
					replace random = . if trt_cash == 0 | (trt_cash == 1 & vtracked == 1)
					
					* Not ANCOVA, dummy outcome 
					foreach var in migration_future_d iga_precovid c3_haveskills c1_headjob c1_hengag_agr chemicals {
					egen rank_`var' = rank(random), by(`var') unique
					gen `var'_lbound = `var'
					replace `var'_lbound = . if (`var' == 1 & trt_cash == 1 & rank_`var' <= 18) | (trt_cash == 1 & vtracked == 1)
					gen `var'_ubound = `var'
					replace `var'_ubound = . if (`var' == 0 & trt_cash == 1 & rank_`var' <= 18) | (trt_cash == 1 & vtracked == 1)
					pdslasso `var'_lbound trt_cash ($balance $X_poly_and_int i.a1_enumerator) , partial(i.a1_enumerator) robust
					store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t_lbound) all
					local n = `e(N)'
					insert_into_file using "sample_table.csv", key(`var'_t_lbound_n) value(" `n'") format(%-9.0fc)
					pdslasso `var'_ubound trt_cash ($balance $X_poly_and_int i.a1_enumerator) , partial(i.a1_enumerator) robust
					store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t_ubound) all
					local n = `e(N)'
					insert_into_file using "sample_table.csv", key(`var'_t_ubound_n) value(" `n'") format(%-9.0fc)
					}
					
					* ANCOVA, dummy outcome
					foreach var in b4_econshock b4_othershock b4_extreme b4_normal migration_d c1_job_iga does_livestock {
					egen rank_`var' = rank(random), by(`var') unique
					gen `var'_lbound = `var'
					replace `var'_lbound = . if (`var' == 1 & trt_cash == 1 & rank_`var' <= 18) | (trt_cash == 1 & vtracked == 1)
					gen `var'_ubound = `var'
					replace `var'_ubound = . if (`var' == 0 & trt_cash == 1 & rank_`var' <= 18) | (trt_cash == 1 & vtracked == 1)
					pdslasso `var'_lbound trt_cash ($balance $X_poly_and_int `var'_bl i.a1_enumerator) , partial(i.a1_enumerator `var'_bl) robust
					store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t_lbound) all
					local n = `e(N)'
					insert_into_file using "sample_table.csv", key(`var'_t_lbound_n) value(" `n'") format(%-9.0fc)
					pdslasso `var'_ubound trt_cash ($balance $X_poly_and_int `var'_bl i.a1_enumerator) , partial(i.a1_enumerator `var'_bl) robust
					store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t_ubound) all
					local n = `e(N)'
					insert_into_file using "sample_table.csv", key(`var'_t_ubound_n) value(" `n'") format(%-9.0fc)
					} 
					
				
					
					* Not ANCOVA, continuous outcome	
					foreach var in z_agency_index z_financial_index c1_othermembersworkn c1_headincome30 c1_incomeotheriga c1_cropprodna c1_cropvalna value19_n_iga d1_ladder_present d1_ladder_1ago d1_ladder3years d1_ladderwealth mhi5 z_assets19_total {
					gen temp = `var' if trt_cash == 1 & vtracked == 0
					sort temp , stable
					gen `var'_ranka = _n if trt_cash == 1 & vtracked == 0 	
					gen temp2 = -`var' if trt_cash == 1 & vtracked == 0
					sort temp2 , stable					
					gen `var'_rankb = _n if trt_cash == 1 & vtracked == 0		
					gen `var'_ubound = `var'
					replace `var'_ubound = . if (trt_cash == 1 & `var'_ranka <= 18) | (trt_cash == 1 & vtracked == 1)
					gen `var'_lbound = `var'
					replace `var'_lbound = . if (trt_cash == 1 & `var'_rankb <= 18) | (trt_cash == 1 & vtracked == 1)
					pdslasso `var'_lbound trt_cash ($balance $X_poly_and_int i.a1_enumerator) , partial(i.a1_enumerator) robust
					store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t_lbound) all
					local n = `e(N)'
					insert_into_file using "sample_table.csv", key(`var'_t_lbound_n) value(" `n'") format(%-9.0fc)
					pdslasso `var'_ubound trt_cash ($balance $X_poly_and_int i.a1_enumerator) , partial(i.a1_enumerator) robust
					store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t_ubound) all
					local n = `e(N)'
					insert_into_file using "sample_table.csv", key(`var'_t_ubound_n) value(" `n'") format(%-9.0fc)
					drop temp temp2
					}
				
				
					* ANCOVA, continuous outcome	
					foreach var in business_profit business_employee total_employement conso_tot_pc conso_food_pc conso_nofood_pc z_assets_total value_n_iga {
					gen temp = `var' if trt_cash == 1 & vtracked == 0
					sort temp , stable
					gen `var'_ranka = _n if trt_cash == 1 & vtracked == 0 	
					gen temp2 = -`var' if trt_cash == 1 & vtracked == 0
					sort temp2 , stable					
					gen `var'_rankb = _n if trt_cash == 1 & vtracked == 0		
					gen `var'_ubound = `var'
					replace `var'_ubound = . if (trt_cash == 1 & `var'_ranka <= 18) | (trt_cash == 1 & vtracked == 1)
					gen `var'_lbound = `var'
					replace `var'_lbound = . if (trt_cash == 1 & `var'_rankb <= 18) | (trt_cash == 1 & vtracked == 1)
					pdslasso `var'_lbound trt_cash ($balance $X_poly_and_int `var'_bl i.a1_enumerator) , partial(i.a1_enumerator `var'_bl) robust
					store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t_lbound) all
					local n = `e(N)'
					insert_into_file using "sample_table.csv", key(`var'_t_lbound_n) value(" `n'") format(%-9.0fc)
					pdslasso `var'_ubound trt_cash ($balance $X_poly_and_int `var'_bl i.a1_enumerator) , partial(i.a1_enumerator `var'_bl) robust
					store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t_ubound) all
					local n = `e(N)'
					insert_into_file using "sample_table.csv", key(`var'_t_ubound_n) value(" `n'") format(%-9.0fc)
					drop temp temp2
					}
			
					drop resp0_* resp1_* 
					
					
					
					
			*** C. Kling and Liebman (columns 3-4)
			* ---------------------------------------
				
					use "${data}/data_women.dta" , clear
					do "${data}/Lasso_var.do"	
					drop if Intervention == "Follow up - TCLP"					
					
					* Assign value to enumerator
					replace a1_enumerator = 99 if a1_enumerator == .
					
					* Analysis not ANCOVA
					foreach var in migration_future_d iga_precovid c3_haveskills c1_hengag_agr chemicals z_financial_index z_agency_index c1_headjob c1_othermembersworkn c1_headincome30 c1_incomeotheriga  c1_cropprodna c1_cropvalna value19_n_iga d1_ladder_present d1_ladder_1ago d1_ladder3years d1_ladderwealth mhi5 z_assets19_total {
					gen `var'_lkling = `var'
					gen `var'_ukling = `var'
					sum `var' if trt_cash == 0
					replace `var'_lkling = `r(mean)'+(0.25*`r(sd)') if trt_cash == 0 & attrition == 1		
					replace `var'_ukling = `r(mean)'-(0.25*`r(sd)') if trt_cash == 0 & attrition == 1
					sum `var' if trt_cash == 1
					replace `var'_lkling = `r(mean)'-(0.25*`r(sd)') if trt_cash == 1 & attrition == 1	
					replace `var'_ukling = `r(mean)'+(0.25*`r(sd)') if trt_cash == 1 & attrition == 1	
					pdslasso `var'_lkling trt_cash ($balance $X_poly_and_int i.a1_enumerator) , partial(i.a1_enumerator) robust
					store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t_lkling) all
					local n = `e(N)'
					insert_into_file using "sample_table.csv", key(`var'_t_lkling_n) value(" `n'") format(%-9.0fc)
					pdslasso `var'_ukling trt_cash ($balance $X_poly_and_int i.a1_enumerator) , partial(i.a1_enumerator) robust
					store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t_ukling) all
					local n = `e(N)'
					insert_into_file using "sample_table.csv", key(`var'_t_ukling_n) value(" `n'") format(%-9.0fc)
					}
					
					* Analysis ANCOVA
					foreach var in b4_econshock b4_othershock b4_extreme b4_normal migration_d c1_job_iga does_livestock business_profit business_employee total_employement conso_tot_pc conso_food_pc conso_nofood_pc z_assets_total value_n_iga {
					gen `var'_lkling = `var'
					gen `var'_ukling = `var'
					sum `var' if trt_cash == 0
					replace `var'_lkling = `r(mean)'+(0.25*`r(sd)') if trt_cash == 0 & attrition == 1		
					replace `var'_ukling = `r(mean)'-(0.25*`r(sd)') if trt_cash == 0 & attrition == 1
					sum `var' if trt_cash == 1
					replace `var'_lkling = `r(mean)'-(0.25*`r(sd)') if trt_cash == 1 & attrition == 1	
					replace `var'_ukling = `r(mean)'+(0.25*`r(sd)') if trt_cash == 1 & attrition == 1	
					pdslasso `var'_lkling trt_cash ($balance $X_poly_and_int i.a1_enumerator `var'_bl) , partial(i.a1_enumerator `var'_bl) robust
					store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t_lkling) all
					local n = `e(N)'
					insert_into_file using "sample_table.csv", key(`var'_t_lkling_n) value(" `n'") format(%-9.0fc)
					pdslasso `var'_ukling trt_cash ($balance $X_poly_and_int i.a1_enumerator `var'_bl) , partial(i.a1_enumerator `var'_bl) robust
					store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t_ukling) all
					local n = `e(N)'
					insert_into_file using "sample_table.csv", key(`var'_t_ukling_n) value(" `n'") format(%-9.0fc)
					}
				
					
			table_from_tpl, t("TPL_tabA6.tex") r("sample_table.csv") o("tabA6.tex")
			table_from_tpl, t("TPL_tabA7.tex") r("sample_table.csv") o("tabA7.tex")
			table_from_tpl, t("TPL_tabA8.tex") r("sample_table.csv") o("tabA8.tex")
					
			
	

* TABLES A9
* --------------
			
	
							
	use "${data}/data_women.dta" , clear
	do "${data}/Lasso_var.do"		

		
		
		
		*** Cost benefit analysis 
		
		** Benefits
		foreach var in conso_tot conso_perpetuity value_assets assetsANDanimals benefit_tot {
					pdslasso `var' trt_cash ($balance $X_poly_and_int i.a1_enumerator) ,  partial(i.a1_enumerator)  robust	
					mat A = r(table)
					local lbound = A[5,1]
					local ubound = A[6,1]
					di `lbound'
					di `ubound'
					store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_cba) all format(%-9.0fc)
					insert_into_file using "sample_table.csv", key(`var'_cba_lbound) value(" `lbound'") format(%-9.0fc)
					insert_into_file using "sample_table.csv", key(`var'_cba_ubound) value(" `ubound'") format(%-9.0fc)
		}
		
		foreach var in value_n_iga { 
					pdslasso `var' trt_cash ($balance $X_poly_and_int `var'_bl i.a1_enumerator) ,  partial(`var'_bl i.a1_enumerator)  robust	
					mat A = r(table)
					local lbound = A[5,1]
					local ubound = A[6,1]
					store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_cba) all format(%-9.0fc)
					insert_into_file using "sample_table.csv", key(`var'_cba_lbound) value(" `lbound'") format(%-9.0fc)
					insert_into_file using "sample_table.csv", key(`var'_cba_ubound) value(" `ubound'") format(%-9.0fc)
		}
		
		** Benefits-cost ratios
		foreach var in costbenefittotal costbenefittotaldisc7 costbenefittotaldisc10  {
					pdslasso `var' trt_cash ($balance $X_poly_and_int i.a1_enumerator) ,  partial(i.a1_enumerator)  robust	
					mat A = r(table)
					local lbound = A[5,1]
					local ubound = A[6,1]
					di `lbound'
					di `ubound'
					store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_cba) all format(%-9.1fc)
					insert_into_file using "sample_table.csv", key(`var'_cba_lbound) value(" `lbound'") format(%-9.1fc)
					insert_into_file using "sample_table.csv", key(`var'_cba_ubound) value(" `ubound'") format(%-9.1fc)
		}
		
		
		** ITT effect on total post-treatment consumption
		pdslasso conso_tot trt_cash ($balance $X_poly_and_int i.a1_enumerator) ,  partial(i.a1_enumerator)  robust	
		local temp1 = -(_b[trt_cash]/ln(1-0.05))
		mat A = r(table)
		local lbound = A[5,1]
		local ubound = A[6,1]
		local temp2 = -`lbound'/ln(1-0.05)
		local temp3 = -`ubound'/ln(1-0.05)
		insert_into_file using "sample_table.csv", key(conso_onward_cba_beta) value(" `temp1'") format(%-9.0fc)
		insert_into_file using "sample_table.csv", key(conso_onward_cba_lbound) value(" `temp2'") format(%-9.0fc)
		insert_into_file using "sample_table.csv", key(conso_onward_cba_ubound) value(" `temp3'") format(%-9.0fc)
		
		** Number of years, such that total benefit = total cost
		pdslasso conso_tot trt_cash ($balance $X_poly_and_int i.a1_enumerator) ,  partial(i.a1_enumerator)  robust	
		local conso = _b[trt_cash]
		pdslasso assetsANDanimals trt_cash ($balance $X_poly_and_int i.a1_enumerator) ,  partial(i.a1_enumerator)  robust	
		local asset = _b[trt_cash]
		local nyears = (1130-`asset')/`conso'
		insert_into_file using "sample_table.csv", key(nyearsbenefcost) value(" `nyears'") format(%-9.1fc)

	
	table_from_tpl, t("TPL_tabA9.tex") r("sample_table.csv") o("tabA9.tex")

		


* TABLES A10-A16
* --------------
		
		
		** Women sample
		
		use "${data}/data_women.dta" , clear
		drop if attrition == 1
		do "${data}/Lasso_var.do"	
		
				* Analysis not ANCOVA
				foreach var in 		b2_assetnum19_sheep_iga b2_assetnum19_duck_iga b2_assetnum19_cows_iga b2_assetnum19_mule_iga b2_assetnum_sheep_iga b2_assetnum_duck_iga b2_assetnum_cows_iga b2_assetnum_mule_iga ///
									c2_borrow_all c2_repaiddebt c2_depositac c2_depositacn ///
									x9_1 x9_2 x9_3 x9_4 x9_5 x9_6 x9_7 x9_largepurchase x9_dailypurchase x9_wifepersonal ///
									x9_borrow x9_lend x9_occupation x9_workplace x9_workhours x9_participation  ///
									b4_sufferevent_10 b4_sufferevent_99 ///
									d1_nervousperson d1_heartedblue d1_cheerup d1_happyperson_transformed d1_calmpeaceful_transformed /// 
									b2_assetnum_room  b2_assetnum_mattresses b2_assetnum_radio b2_assetnum_cellphone b2_assetnum_smartphone b2_assetnum_refrigerator b2_assetnum_bicycles b2_assetnum_moto b2_assetnum_chaise b2_assetnum_tablette b2_assetnum_vent b2_assetnum_clim b2_assetnum_gr b2_assetnum_nat b2_assetnum_poch b2_assetnum_table b2_assetnum_salon b2_assetnum_bibli b2_assetnum_arm b2_assetnum_ferer b2_assetnum_mach b2_assetnum_dec /// 
									c4_hhmigreason_1 c4_hhmigreason_2 c4_hhmigreason_3 c4_hhmigreason_4 c4_hhmigreason_5 c4_hhmigreason_6 c4_hhmigreason_99 {
				sum `var' if trt_cash==0
				local sd = `r(sd)'
				insert_into_file using "sample_table.csv", key(`var'_cmean) value(" `r(mean)'") format(%6.3f)
				insert_into_file using "sample_table.csv", key(`var'_csd) value(" `sd'") format(%6.3f)
				pdslasso `var' trt_cash ($balance $X_poly_and_int i.a1_enumerator) , partial(i.a1_enumerator) robust
				store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t) all
				pdslasso `var' trt_cash_0 trt_cash_1 ($balance $X_poly_and_int i.a1_enumerator) , partial(i.a1_enumerator) robust
				store_est_tpl using "sample_table.csv" , coef(trt_cash_0) name(`var'_t0) all
				store_est_tpl using "sample_table.csv" , coef(trt_cash_1) name(`var'_t1) all
				local n = `e(N)'
				insert_into_file using "sample_table.csv", key(`var'_t1_n) value(" `n'") format(%-9.0fc)
				test trt_cash_0 = trt_cash_1
				insert_into_file using "sample_table.csv", key(`var'_test) value(" `r(p)'") format(%6.3f)
				}
					
				* Analysis ANCOVA
				foreach var in 		c2_borrow12 c2_borrow12n c2_eliipsav c2_eliipsavn c2_loan ///
									b4_business b4_sufferevent_6 b4_sufferevent_8 ///
									b4_death b4_disease b4_sufferevent_5 b4_sufferevent_9  ///
									b4_facesufferevent_1 b4_facesufferevent_2 b4_facesufferevent_7 ///
									b4_debts b4_facesufferevent_6 b4_help b4_sales b4_facesufferevent_15 {
				sum `var' if trt_cash==0
				local sd = `r(sd)'
				insert_into_file using "sample_table.csv", key(`var'_cmean) value(" `r(mean)'") format(%6.3f)
				insert_into_file using "sample_table.csv", key(`var'_csd) value(" `sd'") format(%6.3f)
				pdslasso `var' trt_cash ($balance $X_poly_and_int `var'_bl i.a1_enumerator) , partial(i.a1_enumerator `var'_bl) robust
				store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t) all
				pdslasso `var' trt_cash_0 trt_cash_1 ($balance $X_poly_and_int `var'_bl i.a1_enumerator) , partial(i.a1_enumerator `var'_bl) robust
				store_est_tpl using "sample_table.csv" , coef(trt_cash_0) name(`var'_t0) all
				store_est_tpl using "sample_table.csv" , coef(trt_cash_1) name(`var'_t1) all
				local n = `e(N)'
				insert_into_file using "sample_table.csv", key(`var'_t1_n) value(" `n'") format(%-9.0fc)
				test trt_cash_0 = trt_cash_1
				insert_into_file using "sample_table.csv", key(`var'_test) value(" `r(p)'") format(%6.3f)
				}

				
				
				
		** Partner sample
		
			preserve
			use "${data}/data_partners.dta" , clear
			do "${data}/Lasso_var.do"
			foreach var in z_gender_role z_abilities z_views z_reproductive z_bargaining z_communication {
			sum `var' if trt_cash_part_1==0
			local sd = `r(sd)'
			insert_into_file using "sample_table.csv", key(`var'_cmean) value(" `r(mean)'") format(%6.3f)
			insert_into_file using "sample_table.csv", key(`var'_csd) value(" `sd'") format(%6.3f)
			pdslasso `var' trt_cash_part_1 ($balance $X_poly_and_int i.a1_enumerator) , partial(i.a1_enumerator) robust
			mat A = r(table)
			local p_dialogue = A[4,1]
			di `p_dialogue'
			store_est_tpl using "sample_table.csv" , coef(trt_cash_part_1) name(`var'_t1) all
			}
			restore
		
				
		
		table_from_tpl, t("TPL_tabA10.tex") r("sample_table.csv") o("tabA10.tex")	
		table_from_tpl, t("TPL_tabA11.tex") r("sample_table.csv") o("tabA11.tex")
		table_from_tpl, t("TPL_tabA12.tex") r("sample_table.csv") o("tabA12.tex")
		table_from_tpl, t("TPL_tabA13.tex") r("sample_table.csv") o("tabA13.tex")
		table_from_tpl, t("TPL_tabA14.tex") r("sample_table.csv") o("tabA14.tex")
		table_from_tpl, t("TPL_tabA15.tex") r("sample_table.csv") o("tabA15.tex")	
		table_from_tpl, t("TPL_tabA16.tex") r("sample_table.csv") o("tabA16.tex")	







* TABLES A17-A19
* ----------------


		** Women sample
		
		use "${data}/data_women.dta" , clear
		local i = 1
		gen pvalue_t0 = .
		gen pvalue_t1 = .
		gen pvalue_t2 = .
		gen pvalue_t3 = .
		gen varname = ""

		
		foreach var in 	iga_precovid c3_haveskills c1_headjob c1_othermembersworkn c1_headincome30 c1_incomeotheriga c1_hengag_agr chemicals ///
						value19_n_iga z_financial_index  z_agency_index c1_cropprodna c1_cropvalna ///
						d1_ladder_present d1_ladder_1ago d1_ladder3years d1_ladderwealth mhi5 ///
						z_assets19_total c1_job_iga business_profit business_employee total_employement ///
						value_n_iga does_livestock conso_tot_pc conso_food_pc conso_nofood_pc ///
						z_assets_total b4_econshock b4_othershock b4_extreme b4_normal migration_d hh_migrated migration_future_d {
				
				noi di "`var'"
				replace varname = "`var'" if _n == `i'
				sum `var' if trt_cash == 0
				local sd = `r(sd)'
				insert_into_file using "sample_table.csv", key(`var'_nocontrols_cmean) value(" `r(mean)'") format(%6.3f)
				insert_into_file using "sample_table.csv", key(`var'_nocontrols_csd) value(" `sd'") format(%6.3f)
				
				** Equation 1
				reg `var' trt_cash , ro
				mat A = r(table)
				local p = A[4,1]
				replace pvalue_t0 = `p' if _n == `i'
				store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_nocontrols_t) all
			
				** Equation 2
				reg `var' trt_cash_0 trt_cash_1 ,  ro
				mat A = r(table)
				local p0 = A[4,1]
				replace pvalue_t1 = `p0' if _n == `i'
				local p1 = A[4,2]
				replace pvalue_t2 = `p1' if _n == `i'
				store_est_tpl using "sample_table.csv" , coef(trt_cash_0) name(`var'_nocontrols_t0) all
				store_est_tpl using "sample_table.csv" , coef(trt_cash_1) name(`var'_nocontrols_t1) all				
				local n = `e(N)'
				insert_into_file using "sample_table.csv", key(`var'_t1_nocontrols_n) value(" `n'") format(%-9.0fc)
				test trt_cash_0 = trt_cash_1
				replace pvalue_t3 = `r(p)' if _n == `i'
				local ++i
				insert_into_file using "sample_table.csv", key(`var'_test_nocontrols) value(" `r(p)'") format(%6.3f)
		
		}

		
			
		** Partner sample	
		
		preserve
		use "${data}/data_partners.dta" , clear
		
		foreach var in 	z_male_index {
				sum `var' if trt_cash_part_1==0
				local sd = `r(sd)'
				insert_into_file using "sample_table.csv", key(`var'_nocontrols_cmean) value(" `r(mean)'") format(%6.3f)
				insert_into_file using "sample_table.csv", key(`var'_nocontrols_csd) value(" `sd'") format(%6.3f)
				reg `var' trt_cash_part_1 , ro
				mat A = r(table)
				local p_dialogue = A[4,1]
				di `p_dialogue'
				store_est_tpl using "sample_table.csv" , coef(trt_cash_part_1) name(`var'_t1_nocontrols) all
		}
		restore

		
		
		** FDR q-values
			
			drop if pvalue_t0==. 
			keep pvalue* varname	
			reshape long pvalue_t , i(varname) j(t)
			set obs `=_N+1'
			replace varname = "z_male_index" if _n == 145
			replace pvalue_t = `p_dialogue' if _n == 145
			replace t = 2 if _n == 145
			rename pvalue_t pval
			do "${data}/fdr_sharpened_qvalues.do"
			foreach var in c1_job_iga iga_precovid business_profit business_employee total_employement c3_haveskills c1_headjob c1_othermembersworkn c1_headincome30 c1_incomeotheriga /// 
						c1_hengag_agr chemicals c1_cropprodna c1_cropvalna does_livestock value19_n_iga value_n_iga /// 
						z_financial_index z_agency_index d1_ladder_present d1_ladder_1ago d1_ladder3years d1_ladderwealth mhi5 /// 
						conso_tot_pc conso_food_pc conso_nofood_pc z_assets_total z_assets19_total hh_migrated migration_d migration_future_d b4_econshock b4_othershock b4_extreme b4_normal z_male_index {
			sum bky06_qval if varname == "`var'" & t == 0
			insert_into_file using sample_table.csv, key(`var'_qpvalue_t_nocontrols) value(" `r(mean)'") format(%6.3f)
			sum bky06_qval if varname == "`var'" & t == 1
			insert_into_file using sample_table.csv, key(`var'_qpvalue_t0_nocontrols) value(" `r(mean)'") format(%6.3f)
			sum bky06_qval if varname == "`var'" & t == 2
			insert_into_file using sample_table.csv, key(`var'_qpvalue_t1_nocontrols) value(" `r(mean)'") format(%6.3f)
			sum bky06_qval if varname == "`var'" & t == 3
			insert_into_file using sample_table.csv, key(`var'_qpvalue_test_nocontrols) value(" `r(mean)'") format(%6.3f) 
			}

		
		table_from_tpl, t("TPL_tabA17.tex") r("sample_table.csv") o("tabA17.tex")	
		table_from_tpl, t("TPL_tabA18.tex") r("sample_table.csv") o("tabA18.tex")	
		table_from_tpl, t("TPL_tabA19.tex") r("sample_table.csv") o("tabA19.tex")	
	
		
	
	

* TABLE A20
* ----------

		use "${data}/data_women.dta" , clear
		drop if attrition == 1
		do "${data}/Lasso_var.do"

			foreach var in 	c1_job_iga_1 c1_wageprimjob c1_activsearchwork c1_activsearchwork_6m c1_activsearchwork_12m ///
							z_social z_civic i2_taxesintro z_antisoc z_prosoc z_victimization z_conflict {
			sum `var' if trt_cash==0
			local sd = `r(sd)'
			insert_into_file using "sample_table.csv", key(`var'_cmean) value(" `r(mean)'") format(%6.3f)
			insert_into_file using "sample_table.csv", key(`var'_csd) value(" `sd'") format(%6.3f)
			pdslasso `var' trt_cash ($balance $X_poly_and_int i.a1_enumerator) , partial(i.a1_enumerator) robust
			local n = `e(N)'
			insert_into_file using "sample_table.csv", key(`var'_t1_n) value(" `n'") format(%-9.0fc)
			store_est_tpl using "sample_table.csv" , coef(trt_cash) name(`var'_t) all
			pdslasso `var' trt_cash_0 trt_cash_1 ($balance $X_poly_and_int i.a1_enumerator) , partial(i.a1_enumerator) robust
			store_est_tpl using "sample_table.csv" , coef(trt_cash_0) name(`var'_t0) all
			store_est_tpl using "sample_table.csv" , coef(trt_cash_1) name(`var'_t1) all
			test trt_cash_0 = trt_cash_1
			insert_into_file using "sample_table.csv", key(`var'_test) value(" `r(p)'") format(%6.3f)
			}
	
	
		table_from_tpl, t("TPL_tabA20.tex") r("sample_table.csv") o("tabA20.tex")









* TABLES A21-A23
* ----------------

		use "${data}/data_women.dta" , clear
		drop if attrition==1
		do "${data}/Lasso_var2.do"

		replace tclp = . if tclp_missing == 1
		
		global hetero		c1_job_iga_bl married_b conso2_bl tclp
		global balance		woman_b repondant_age_b secondary_b  origine_naissance_b relation_head_b relation_spouse_b relation_daughter_b relation_other_b initiatives_2_b formation_b ///
			   				hhsize_b children_b adults_b elderly_b dirtfloor_b thatched_still_b proprietaire_terre_b livestock_b /// 
							distance_cheflieu_b distance_marche_b distance_transpublic_b distance_ecoleprim_b distance_eau_b 
		/* No good data on woman empowerment at baseline 
		Only 19 women responded to the question: Est-ce que vous décidez seule de la manière dont vous utilisez l'argent que vous gagnez ?
		(for other women the question was not asked because they said no to: Est-ce que vous avez gagné de l’argent au cours des 6 derniers mois ?) */
							
							
			foreach x in $hetero {
					gen interaction = trt_cash*`x'
					foreach var in c1_job_iga iga_precovid business_profit business_employee total_employement c3_haveskills c1_headjob c1_othermembersworkn c1_headincome30 c1_incomeotheriga /// 
						c1_hengag_agr chemicals c1_cropprodna c1_cropvalna does_livestock value19_n_iga value_n_iga /// 
						z_financial_index z_agency_index d1_ladder_present d1_ladder_1ago d1_ladder3years d1_ladderwealth mhi5 /// 
						conso_tot_pc conso_food_pc conso_nofood_pc z_assets_total z_assets19_total migration_d migration_future_d b4_econshock b4_othershock b4_extreme b4_normal  {
					pdslasso `var' trt_cash `x' interaction ($balance $X_poly_and_int i.a1_enumerator) , partial(i.a1_enumerator) robust
					store_est_tpl using "sample_table.csv" , coef(trt_cash) name(hte1_`var'_`x') all
					local n = `e(N)'
					insert_into_file using "sample_table.csv", key(hte1_`var'_`x'_n) value(" `n'") format(%-9.0fc)
					store_est_tpl using "sample_table.csv" , coef(interaction) name(hte3_`var'_`x') all
					local n = `e(N)'
					insert_into_file using "sample_table.csv", key(hte3_`var'_`x'_n) value(" `n'") format(%-9.0fc)
					lincom trt_cash + interaction
					local coef = `r(estimate)'
					local se = `r(se)'
					local text : di %6.3f `coef'
					local pvalue = `r(p)'
					count_stars, p(`pvalue')
					insert_into_file using sample_table.csv, key(hte_`var'_`x'_starbeta) value(" `text'`r(stars)'") format(%6.3f)
					insert_into_file using sample_table.csv, key(hte_`var'_`x'_se) value(" `se'") format(%6.3f)
					}
					drop interaction
					}
			
		
		
		table_from_tpl, t("TPL_tabA21.tex") r("sample_table.csv") o("tabA21.tex")
		table_from_tpl, t("TPL_tabA22.tex") r("sample_table.csv") o("tabA22.tex")
		table_from_tpl, t("TPL_tabA23.tex") r("sample_table.csv") o("tabA23.tex")
	
		
		
							********************************************************	
							****** Robustness checks to adding other HTE*************
							********************************************************
							
							cap drop interaction
							
							global balance_hte 
							foreach var in $balance {
							cap drop hte_`var'
							gen hte_`var'  = trt_cash*`var'
							global balance_hte $balance_hte hte_`var'
							}
							
							
							tab a1_enumerator , gen(a1_enumerator)
							global enumerator_list a1_enumerator2 a1_enumerator3 a1_enumerator4 a1_enumerator5 a1_enumerator6 a1_enumerator7 a1_enumerator8 a1_enumerator9 a1_enumerator10 a1_enumerator11 a1_enumerator12 a1_enumerator13 a1_enumerator14 a1_enumerator15 a1_enumerator16 a1_enumerator17 a1_enumerator18 a1_enumerator19 a1_enumerator20 a1_enumerator21 a1_enumerator22 a1_enumerator23 a1_enumerator24
							
							
							************************************
							* job at baseline (c1_job_iga_bl) 
							***************************************
							
							* does_livestock: robust
							cap drop interaction 
							gen interaction = trt_cash*c1_job_iga_bl
							pdslasso does_livestock trt_cash c1_job_iga_bl interaction  ($balance $balance_hte $X_poly_and_int $enumerator_list ) , partial($balance $balance_hte $enumerator_list) robust
							
							
							* b4_othershock: robust
							cap drop interaction 
							gen interaction = trt_cash*c1_job_iga_bl
							pdslasso b4_othershock trt_cash c1_job_iga_bl interaction  ($balance $balance_hte $X_poly_and_int $enumerator_list ) , partial($balance $balance_hte $enumerator_list) robust
							
							
							************************************
							* married at baseline (married_b) 
							***************************************
							
							* Other HH members income (in Dinars): c1_incomeotheriga  -- > NOT ROBUST
							cap drop interaction 
							gen interaction = trt_cash*married_b
							pdslasso value19_n_iga trt_cash c1_incomeotheriga interaction  ($balance $balance_hte $X_poly_and_int $enumerator_list ) , partial($balance $balance_hte $enumerator_list) robust
							
							
							* Number of other HH members with an IGA: c1_othermembersworkn -- > NOT ROBUST
							cap drop interaction 
							gen interaction = trt_cash*married_b
							pdslasso value19_n_iga trt_cash c1_othermembersworkn interaction  ($balance $balance_hte $X_poly_and_int $enumerator_list ) , partial($balance $balance_hte $enumerator_list) robust
							
							
							* Livestock Bought since January 2019 (in Dirhams): value19_n_iga -- > NOT ROBUST
							cap drop interaction 
							gen interaction = trt_cash*married_b
							pdslasso value19_n_iga trt_cash married_b interaction  ($balance $balance_hte $X_poly_and_int $enumerator_list ) , partial($balance $balance_hte $enumerator_list) robust
							
							
							* Women empowerment: z_agency_index -- > NOT ROBUST
							cap drop interaction 
							gen interaction = trt_cash*married_b
							pdslasso z_agency_index trt_cash married_b interaction  ($balance $balance_hte $X_poly_and_int $enumerator_list ) , partial($balance $balance_hte $enumerator_list) robust
							
							
							* Women Financial Index: z_financial_index -- > NOT ROBUST
							cap drop interaction 
							gen interaction = trt_cash*married_b
							pdslasso z_financial_index trt_cash married_b interaction  ($balance $balance_hte $X_poly_and_int $enumerator_list ) , partial($balance $balance_hte $enumerator_list) robust
							
							
							* Relative wealth: d1_ladderwealth -- > NOT ROBUST
							cap drop interaction 
							gen interaction = trt_cash*married_b
							pdslasso d1_ladderwealth trt_cash married_b interaction  ($balance $balance_hte $X_poly_and_int $enumerator_list ) , partial($balance $balance_hte $enumerator_list) robust
							
							
							* Food consumption per capita: conso_food_pc  -- > NOT ROBUST
							cap drop interaction 
							gen interaction = trt_cash*married_b
							pdslasso conso_food_pc  trt_cash married_b interaction  ($balance $balance_hte $X_poly_and_int $enumerator_list ) , partial($balance $balance_hte $enumerator_list) robust
								
							
									
							************************************
							* conso at baseline (conso2_bl) 
							***************************************		
								
								
							
							* Used chemicals: chemicals  -- > NOT ROBUST
							cap drop interaction 
							gen interaction = trt_cash*conso2_bl
							pdslasso chemicals trt_cash conso2_bl interaction  ($balance $balance_hte $X_poly_and_int $enumerator_list ) , partial($balance $balance_hte $enumerator_list) robust
							
							* Value of the production: c1_cropvalna  -- > NOT ROBUST
							cap drop interaction 
							gen interaction = trt_cash*conso2_bl
							pdslasso c1_cropvalna trt_cash conso2_bl interaction  ($balance $balance_hte $X_poly_and_int $enumerator_list ) , partial($balance $balance_hte $enumerator_list) robust
							
							* Women financial index: z_financial_index
							cap drop interaction 
							gen interaction = trt_cash*conso2_bl
							pdslasso z_financial_index trt_cash conso2_bl interaction  ($balance $balance_hte $X_poly_and_int $enumerator_list ) , partial($balance $balance_hte $enumerator_list) robust
								
								
							* Livestock Bought since January 2019 (in Dirhams): value19_n_iga -- > NOT ROBUST
							cap drop interaction 
							gen interaction = trt_cash*conso2_bl
							pdslasso value19_n_iga trt_cash conso2_bl interaction  ($balance $balance_hte $X_poly_and_int $enumerator_list ) , partial($balance $balance_hte $enumerator_list) robust
							
							
							
							************************************
							* tclp beneficiaries (tclp) 
							***************************************						
							
							
							* Agriculture, quantity produced: c1_cropvalna -- > NOT ROBUST
							cap drop interaction 
							gen interaction = trt_cash*tclp
							pdslasso  c1_cropvalna trt_cash tclp interaction  ($balance $balance_hte $X_poly_and_int $enumerator_list ) , partial($balance $balance_hte $enumerator_list) robust
							



							
* TABLES A24-A26
* ----------------		
		
		use "${data}/data_women.dta" , clear
		drop if attrition==1
		
			** Predicted outcome using RSS endogenous stratification
			** Predict each of our five outcomes using the repeated split sample (RSS) procedure developed by Abadie et al. (2018). 
			** We use 100 repetitions and all baseline controls as predictors (including outcomes). 
			set seed 123456789	
			* enumfe
			levelsof a1_enumerator, local(levels) 
			foreach l of local levels {
			gen enum_`l' = 1 if a1_enumerator == `l'
			replace enum_`l' = 0 if enum_`l' == .
			}
			global enumfe enum_2 enum_3 enum_5 enum_6 enum_7 enum_8 enum_9 enum_10 enum_11 enum_12 enum_13 enum_14 enum_15 enum_16 enum_17 enum_18 enum_19 enum_20 enum_21 enum_24 enum_25 enum_27 enum_28 enum_29
			* estimates
			foreach var in c1_job_iga iga_precovid business_profit business_employee total_employement c3_haveskills c1_headjob c1_othermembersworkn c1_headincome30 c1_incomeotheriga /// 
						c1_hengag_agr chemicals c1_cropprodna c1_cropvalna does_livestock value19_n_iga value_n_iga /// 
						z_financial_index z_agency_index d1_ladder_present d1_ladder_1ago d1_ladder3years d1_ladderwealth mhi5 /// 
						conso_tot_pc conso_food_pc conso_nofood_pc z_assets_total z_assets19_total migration_d migration_future_d b4_econshock b4_othershock b4_extreme b4_normal  {
			reg `var' trt_cash $balance $baseline_outcomes $enumfe, robust
			local degreesf = e(df_r)
			estrat2 `var' trt_cash $balance $baseline_outcomes  , groups(3) reps(100) boot(100) rss_only cov($enumfe)
			matrix coefb=e(RSS_C)
			matrix se = e(RSS_SE)
			matrix colnames se = c1 c2 c3
			matrix VV1 = se'*se	
			mat b=e(RSS_C)
			mat c=e(RSS_SE)
			forvalues x=1/3 {
			local coef=(coefb[1,`x']) 
			local se=(se[1,`x']) 
			local text : di %6.3f `coef'
			local pvalue = (2 * ttail(`degreesf', abs(`coef'/`se')))
			count_stars, p(`pvalue')
			insert_into_file using sample_table.csv, key(`var'_rss`x'_starbeta) value(" `text'`r(stars)'") format(%6.3f)
			insert_into_file using sample_table.csv, key(`var'_rss`x'_se) value(" `se'") format(%6.3f)
			}
			local ttest12_t = (coefb[1,2] - coefb[1,1]) /(sqrt((se[1,2])^2+(se[1,1])^2))
			local ttest12_p = 2*ttail( `degreesf' ,abs(`ttest12_t'))
			local ttest13_t = (coefb[1,3] - coefb[1,1]) /(sqrt((se[1,3])^2+(se[1,1])^2))
			local ttest13_p = 2*ttail( `degreesf' ,abs(`ttest13_t'))
			local ttest23_t = (coefb[1,3] - coefb[1,2]) /(sqrt((se[1,3])^2+(se[1,2])^2))
			local ttest23_p = 2*ttail( `degreesf' ,abs(`ttest23_t'))
			insert_into_file using sample_table.csv, key(`var'_rss_p12) value(" `ttest12_p'") format(%6.3f)
			insert_into_file using sample_table.csv, key(`var'_rss_p13) value(" `ttest13_p'") format(%6.3f)
			insert_into_file using sample_table.csv, key(`var'_rss_p23) value(" `ttest23_p'") format(%6.3f)
			}

		
	table_from_tpl, t("TPL_tabA24.tex") r("sample_table.csv") o("tabA24.tex")
	table_from_tpl, t("TPL_tabA25.tex") r("sample_table.csv") o("tabA25.tex")
	table_from_tpl, t("TPL_tabA26.tex") r("sample_table.csv") o("tabA26.tex")

	






* FIGURE A5
* ----------			
				
	use "${data}/data_women.dta" , clear
		
		drop if Intervention == "Follow up - TCLP"
		global plotregion 		plotregion(lcolor(black))
		global graphregion 		graphregion(color(white) margin(5 5 5 5))
		global legendregion 	region(lstyle(none) fcolor(white) lcolor(white) icolor(white) ifcolor(white) ilcolor(white)) size(medsmall) colgap(huge) keygap(vsmall) just(center) symxsize(huge))
		global laboptions		labsize(4) nogextend nogrid
		global titleoptions		size(large)
		graph set ps fontface 	"Times New Roman"
			
			* Panel A
			#delimit ;
				twoway (histogram  diff_date if trt_cash == 1 & vtracked == 1, color(gs2%90) frequency width(1)) 
				(histogram  diff_date if trt_cash == 1 , color(gs2%30) frequency width(1)) , 
				// kdensity kdenopts(lcolor(gs3)) 
				xline(30.5, lcolor(red)) 
				xtitle("Date of interview relative to median date in Imada", $titleoptions) 
				xlabel(-10(10)100 , $laboptions )  
				ytitle("Frequency", $titleoptions)
				xsize(6)
				ylabel(0(100)300, $laboptions)
				legend(order(2 1) position(0) bplacement(neast) size(medium) cols(1) region(lwidth(vthin)) label(2 "All HH tracked (N)") label(1 "HH intensively tracked (N)"))
				$plotregion $graphregion ;
			#delimit cr	
			graph export "${figures}/figA5a.png", as(png) replace
			
			* Panel B
			replace diff_date = . if diff_date < 5	
			#delimit ;
				twoway (histogram  diff_date if trt_cash == 1 & vtracked == 1 , color(gs2%90) frequency start(0) width(1)) 
				(histogram  diff_date if trt_cash == 1 , color(gs2%30) frequency start(0) width(1)), 
				xline(30.5, lcolor(red)) 
				xtitle("Date of interview relative to median date in Imada", $titleoptions) 
				xlabel(5(15)95, $laboptions )  
				ytitle("Frequency", $titleoptions)
				xsize(6)
				ylabel(0(5)15, $laboptions)
				legend(order(2 1) position(0) bplacement(neast) size(medium) cols(1) region(lwidth(vthin)) label(2 "All HH tracked (N)") label(1 "HH intensively tracked (N)"))
				$plotregion $graphregion ;
			#delimit cr	
			graph export "${figures}/figA5b.png", as(png) replace
			
